==> diogenes_0.9.12.orig.tar.gz: diogenes-0.9.12/include/admin/index.php <==
<?php
require_once 'diogenes.common.inc.php';
require_once 'diogenes.admin.inc.php';

$page = new DiogenesAdmin;

// retrieve recent events
$res = $globals->db->query("select e.action,e.stamp,e.data,a.text,s.auth,s.uid "
                  ."from {$globals->table_log_events} as e "
                  ."left join {$globals->table_log_actions} as a on e.action=a.id "
                  ."left join {$globals->table_log_sessions} as s on e.session=s.id "
                  ."where e.data like '{$page->alias}:%' "
                  ."order by stamp desc limit 0,10");
while ($myarr = mysql_fetch_array($res)) {
  $myarr['username'] = call_user_func(array($globals->session,'getUsername'),$myarr['auth'],$myarr['uid']);
  $pieces = split(":",$myarr['data']);
  $myarr['file'] = $pieces[1];
  switch($myarr['text']) {
  case "barrel_create":
    $myarr['desc'] = __("site created");
    break;
  case "page_create":
    $myarr['desc'] = array(__("page created"),"pages?PID={$myarr['file']}");
    break;
  case "page_delete":
    $myarr['desc'] = __("page deleted");
    break;
  case "rcs_commit":
    $myfile = basename($myarr['file']);
    $mydir = dirname($myarr['file']);
    $myarr['desc'] = array(__("file updated"),"files?action=revs&amp;dir=$mydir&amp;target=$myfile");
    break;
  case "rcs_delete":
    $myarr['desc'] = __("file removed");
    break;
  }
  if (isset($myarr['desc']))
    $page->append('events',$myarr);
}
mysql_free_result($res);

// do display
$page->assign('greeting',__("Welcome to the Diogenes backoffice"));
$page->assign('msg_date',__("date"));
$page->assign('msg_user',__("user"));
$page->assign('msg_event',__("event"));
$page->display('admin-index.tpl');
?>

==> diogenes_0.9.16.orig.tar.gz: diogenes-0.9.16/include/admin/index.php <==
<?php
require_once 'diogenes.common.inc.php';
require_once 'diogenes.admin.inc.php';

$page = new DiogenesAdmin;

// filename transformations
function makeFileLoc($log_file) {
  global $globals, $page;

  if (stristr($log_file, '/') == FALSE ) {
    // this is a directory
    $mydir = $log_file;
    $myfile = '';
  } else {
    $myfile = basename($log_file);
    $mydir = dirname($log_file);
  }
    
  $res2 = $globals->db->query("select location from {$page->table_page} where PID='$mydir'");
  if (list($myloc) = mysql_fetch_row($res2))
  {
    $log_file = $myloc ? "$myloc/$myfile" : $myfile;
  }
  mysql_free_result($res2);      
  
  return array($log_file, $mydir, $myfile);
}


// retrieve recent events
$res = $globals->db->query("select e.action,e.stamp,e.data,a.text,s.auth,s.uid "
                  ."from {$globals->table_log_events} as e "
                  ."left join {$globals->table_log_actions} as a on e.action=a.id "
                  ."left join {$globals->table_log_sessions} as s on e.session=s.id "
                  ."where e.data like '{$page->alias}:%' "
                  ."order by stamp desc limit 0,10");
while ($myarr = mysql_fetch_array($res)) {
  $myarr['username'] = call_user_func(array($globals->session,'getUsername'),$myarr['auth'],$myarr['uid']);
  list($op_alias, $op_file) = split(":",$myarr['data']);

  switch($myarr['text']) {
  case "barrel_create":
    $myarr['desc'] = __("site created");
    break;
  
  case "page_create":
    list($op_file, $mydir, $myfile) = makeFileLoc($op_file);
    $myarr['desc'] = array(__("page created"),"pages?PID=$op_file");  
    break;

  case "page_delete":
    $myarr['desc'] = __("page deleted");
    break;
        
  case "rcs_commit": 
    list($op_file, $mydir, $myfile) = makeFileLoc($op_file);  
    $myarr['desc'] = array(__("file updated"),"files?action=revs&amp;dir=$mydir&amp;target=$myfile");        
    break;
      
  case "rcs_delete":
    list($op_file, $mydir, $myfile) = makeFileLoc($op_file);    
    $myarr['desc'] = __("file removed");        
    break;
    
  }
    
  $myarr['file'] = $op_file;

  if (isset($myarr['desc']))
    $page->append('events',$myarr);
}
mysql_free_result($res);

// do display
$page->assign('greeting',__("Welcome to the Diogenes backoffice"));
$page->assign('msg_date',__("date"));
$page->assign('msg_user',__("user"));
$page->assign('msg_event',__("event"));
$page->display('admin-index.tpl');
?>
